use 'ares_srv_reply' for proper name-spacing
authorDaniel Stenberg <daniel@haxx.se>
Thu, 29 Oct 2009 08:50:34 +0000 (08:50 +0000)
committerDaniel Stenberg <daniel@haxx.se>
Thu, 29 Oct 2009 08:50:34 +0000 (08:50 +0000)
ares.h
ares_parse_srv_reply.c

diff --git a/ares.h b/ares.h
index 88805e3..4a53cec 100644 (file)
--- a/ares.h
+++ b/ares.h
@@ -429,7 +429,7 @@ struct addr6ttl {
   int             ttl;
 };
 
-struct srv_reply {
+struct ares_srv_reply {
   unsigned short weight;
   unsigned short priority;
   unsigned short port;
@@ -469,7 +469,7 @@ CARES_EXTERN int ares_parse_ns_reply(const unsigned char *abuf,
 
 CARES_EXTERN int ares_parse_srv_reply(const unsigned char* abuf,
                                       int alen,
-                                      struct srv_reply** srv_out,
+                                      struct ares_srv_reply** srv_out,
                                       int *nsrvreply);
 
 CARES_EXTERN void ares_free_string(void *str);
index c26d59f..b0e15eb 100644 (file)
 
 int
 ares_parse_srv_reply (const unsigned char *abuf, int alen,
-                      struct srv_reply **srv_out, int *nsrvreply)
+                      struct ares_srv_reply **srv_out, int *nsrvreply)
 {
   unsigned int qdcount, ancount;
   const unsigned char *aptr;
   int status, i, rr_type, rr_class, rr_len;
   long len;
   char *hostname = NULL, *rr_name = NULL;
-  struct srv_reply *srv = NULL;
+  struct ares_srv_reply *srv = NULL;
 
   /* Set *srv_out to NULL for all failure cases. */
   if (srv_out)
@@ -95,8 +95,8 @@ ares_parse_srv_reply (const unsigned char *abuf, int alen,
     }
   aptr += len + QFIXEDSZ;
 
-  /* Allocate srv_reply array; ancount gives an upper bound */
-  srv = malloc ((ancount) * sizeof (struct srv_reply));
+  /* Allocate ares_srv_reply array; ancount gives an upper bound */
+  srv = malloc ((ancount) * sizeof (struct ares_srv_reply));
   if (!srv)
     {
       free (hostname);